# WinColl

https://github.com/rrthomas/wincoll  

by Reuben Thomas <rrt@sc3d.org>  

WinColl is a simple puzzle game in which you tunnel through caverns
collecting diamonds while avoiding being squashed by falling rocks. It is
based on [Repton](https://en.wikipedia.org/wiki/Repton_(video_game)) (but
without eggs and monsters).

I originally wrote WinColl for Acorn RISC OS. Original and updated [RISC OS
versions](<https://github.com/rrthomas/wincoll/RISC OS.md>) are available.

The name of the game is an abbreviation of my school’s. “Repton” is also the name of a school, but I don’t believe the game was named after it!


## Credits

Level design and graphics also by Alistair Turnbull, Paul Smith and Jeremy
Douglas. Paul also designed the title graphic.

The sounds are from [Freesound](https://freesound.org), lightly adapted.


## Installation and use

Install with `pip`: `pip install wincoll`, then execute the command
`wincoll`. The game provides instructions on how to play.

You can edit the levels (the `.tmx` files) with
[Tiled](https://www.mapeditor.org/).


## Copyright and Disclaimer

WinColl is distributed under the GNU Public License version 3, or, at your
option, any later version. See the file COPYING.

THIS PROGRAM IS PROVIDED AS IS, WITH NO WARRANTY. USE IS AT THE USER'S RISK.
WinColl’s code is copyright Reuben Thomas, and its levels and graphics by Reuben Thomas, Alistair Turnbull, Paul Smith and Jeremy Douglas.

The font “Acorn Mode 1”, which is based on the design of Acorn computers’ system font, as used on the Acorn Archimedes on which WinColl was originally written, is by p1.mark and licensed under CC BY-SA 3.0.

The sound effects are copyrighted and licensed as follows:

+ Diamond collection:
  [Ding.wav by datasoundsample](https://freesound.org/s/638638/) under CC
  BY 4.0
+ Rock fall:
  [WHITE_NOISE-10s.wav by newagesoup](https://freesound.org/s/349315/)
  under CC 0
+ Safe unlock:
  [Old Church Bell (no noise) by igroglaz](https://freesound.org/s/633208/)
  under CC 0
+ Death splat:
  [Splat1.wav by Shakedown_M](https://freesound.org/s/685205/) under CC 0
